DocType enum
Supported document types for UniversalDockit.
Map file extensions to DocType values and pass them to openDocument.
Values
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
Returns the string identifier used by the native layer.
no setter
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromExtension(
String ext) → DocType - Infers the DocType from a raw extension string (without the dot). Throws ArgumentError if the extension is unrecognised.
-
fromPath(
String filePath) → DocType - Infers the DocType from a file path extension. Throws ArgumentError if the extension is unrecognised.