identifier property
String
get
identifier
Returns the string identifier used by the native layer.
Implementation
String get identifier => name;
Returns the string identifier used by the native layer.
String get identifier => name;