methodChannel property
The method channel name must match the one declared in native code.
Implementation
@visibleForTesting
final methodChannel = const MethodChannel('universal_dockit');
The method channel name must match the one declared in native code.
@visibleForTesting
final methodChannel = const MethodChannel('universal_dockit');