DocumentFeatures class

Constructors

DocumentFeatures({bool openLocalFile = true, bool openFromUrl = true, bool zoomInOut = true, bool search = true, bool shareDocument = true, bool fileInformation = true, bool offlineViewing = true, bool darkMode = false, bool pageNavigation = true, bool sheetNavigation = true, bool slideNavigation = true, bool thumbnails = true, bool textSelection = true, bool richTextRendering = true, bool renderImages = true, bool renderTables = true, bool renderHyperlinks = true, bool cellFormatting = true, bool freezePanes = true, bool wordWrap = true, bool cssSupport = true})
const

Properties

cellFormatting bool
final
cssSupport bool
final
darkMode bool
final
fileInformation bool
final
freezePanes bool
final
hashCode int
The hash code for this object.
no setterinherited
offlineViewing bool
final
openFromUrl bool
final
openLocalFile bool
final
final
final
renderImages bool
final
renderTables bool
final
richTextRendering bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
final
shareDocument bool
final
sheetNavigation bool
final
slideNavigation bool
final
textSelection bool
final
thumbnails bool
final
wordWrap bool
final
zoomInOut bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited