UniversalDockitPlatform class abstract
Abstract platform interface for UniversalDockit.
Platform implementations must extend this class (not implement it) and register themselves as the instance singleton.
- Inheritance
-
- Object
- PlatformInterface
- UniversalDockitPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> - Returns the platform version string (used for diagnostics).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openDocument(
{required String filePath, required DocType docType, DocumentFeatures features = const DocumentFeatures()}) → Future< bool> -
Opens the document at
filePathusing the native viewer. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ UniversalDockitPlatform
-
The default instance, backed by MethodChannelUniversalDockit.
getter/setter pair